translate.misc.progressbar

Package translate :: Package misc :: Module progressbar |
[hide private]
[frames] | no frames]

# Module progressbar

source code

Progress bar utilities for reporting feedback on the progress of an application.

Classes | [hide private]
| DotsProgressBar An ultra-simple progress indicator that just writes a dot for each action
| NoProgressBar An invisible indicator that does nothing.
| ProgressBar A plain progress bar that doesn't know very much about output.
| MessageProgressBar A ProgressBar that just writes out the messages without any progress display
| HashProgressBar A ProgressBar which knows how to go back to the beginning of the line.
| VerboseProgressBar

Functions | [hide private]
test(progressbar) | source code